@@ -2,6 +2,7 @@
 
 from pax import experimental, nets, utils
 from pax._src.core import (
+    EmptyNode,
     Module,
     ParameterModule,
     StateModule,
@@ -48,7 +49,7 @@ from pax._src.nn import (
 from pax._src.nn.dropout import dropout
 from pax._src.utils import build_update_fn, grad, scan, value_and_grad
 
-__version__ = "0.5.1"
+__version__ = "0.5.2"
 
 __all__ = (
     "apply_mp_policy",
@@ -65,6 +66,7 @@ __all__ = (
     "Dropout",
     "EMA",
     "Embed",
+    "EmptyNode",
     "enable_eval_mode",
     "enable_train_mode",
     "experimental",
