@@ -4,18 +4,17 @@
 # https://jax.readthedocs.io/en/latest/notebooks/convolutions.html
 #
 
-from typing import Optional, Sequence, Tuple, Union
+from typing import Callable, Optional, Sequence, Tuple, Union
 
 import jax
 import jax.numpy as jnp
 import numpy as np
 
-from .. import initializers
-from ..core import Module
+from ..core import ParameterModule
 from ..core.rng import KeyArray, next_rng_key
 
 
-class Conv(Module):
+class Conv(ParameterModule):
     """Convolution Base Class."""
 
     weight: jnp.ndarray
@@ -30,8 +29,8 @@ class Conv(Module):
         rate: Union[int, Sequence[int]] = 1,
         padding: Union[str, Sequence[Tuple[int, int]]] = "SAME",
         with_bias: bool = True,
-        w_init: Optional[initializers.Initializer] = None,
-        b_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
+        b_init: Optional[Callable] = None,
         data_format=None,
         *,
         name: Optional[str] = None,
@@ -86,15 +85,15 @@ class Conv(Module):
 
         if w_init is None:
             fan_in = np.prod(w_shape[:-1])
-            w_init = initializers.truncated_normal(stddev=1.0 / np.sqrt(fan_in))
+            w_init = jax.nn.initializers.normal(stddev=1.0 / np.sqrt(fan_in))
 
-        self.register_parameter("weight", w_init(w_shape, jnp.float32, w_rng_key))
+        self.weight = w_init(w_rng_key, w_shape)
 
         if with_bias:
             if b_init is None:
-                b_init = initializers.zeros
+                b_init = jax.nn.initializers.zeros
             b_shape = [out_features]
-            self.register_parameter("bias", b_init(b_shape, jnp.float32, b_rng_key))
+            self.bias = b_init(b_rng_key, b_shape)
         else:
             self.bias = None
 
@@ -155,7 +154,7 @@ class Conv(Module):
         if all_one(info["stride"]):
             del info["stride"]
 
-        return super()._repr(info)
+        return self._repr(info)
 
 
 class Conv1D(Conv):
@@ -170,8 +169,8 @@ class Conv1D(Conv):
         rate: Union[int, Sequence[int]] = 1,
         padding: Union[str, Sequence[Tuple[int, int]]] = "SAME",
         with_bias: bool = True,
-        w_init: Optional[initializers.Initializer] = None,
-        b_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
+        b_init: Optional[Callable] = None,
         data_format: str = "NWC",
         *,
         name: Optional[str] = None,
@@ -193,8 +192,7 @@ class Conv1D(Conv):
                 ``rate > 1`` corresponds to dilated convolution. Defaults to 1.
             padding: Optional padding. Either ``VALID`` or ``SAME`` or
                 sequence of `Tuple[int, int]` representing the padding before and after
-                for each spatial dimension. Defaults to ``SAME``. See:
-                https://www.tensorflow.org/xla/operation_semantics#conv_convolution.
+                for each spatial dimension. Defaults to ``SAME``.
             with_bias: Whether to add a bias. By default, true.
             w_init: Optional weight initialization. By default, truncated normal.
             b_init: Optional bias initialization. By default, zeros.
@@ -236,8 +234,8 @@ class Conv2D(Conv):
         rate: Union[int, Sequence[int]] = 1,
         padding: Union[str, Sequence[Tuple[int, int]]] = "SAME",
         with_bias: bool = True,
-        w_init: Optional[initializers.Initializer] = None,
-        b_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
+        b_init: Optional[Callable] = None,
         data_format: str = "NHWC",
         *,
         name: Optional[str] = None,
@@ -259,8 +257,7 @@ class Conv2D(Conv):
                 ``rate > 1`` corresponds to dilated convolution. Defaults to 1.
             padding: Optional padding. Either ``VALID`` or ``SAME`` or
                 sequence of `Tuple[int, int]` representing the padding before and after
-                for each spatial dimension. Defaults to ``SAME``. See:
-                https://www.tensorflow.org/xla/operation_semantics#conv_convolution.
+                for each spatial dimension. Defaults to ``SAME``.
             with_bias: Whether to add a bias. By default, true.
             w_init: Optional weight initialization. By default, truncated normal.
             b_init: Optional bias initialization. By default, zeros.
@@ -290,7 +287,7 @@ class Conv2D(Conv):
         )
 
 
-class ConvTranspose(Module):
+class ConvTranspose(ParameterModule):
     """Convolution Transpose Base Class."""
 
     weight: jnp.ndarray
@@ -304,8 +301,8 @@ class ConvTranspose(Module):
         stride: Union[int, Sequence[int]] = 1,
         padding: Union[str, Sequence[Tuple[int, int]]] = "SAME",
         with_bias: bool = True,
-        w_init: Optional[initializers.Initializer] = None,
-        b_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
+        b_init: Optional[Callable] = None,
         data_format=None,
         *,
         name: Optional[str] = None,
@@ -352,13 +349,13 @@ class ConvTranspose(Module):
 
         if w_init is None:
             fan_in = np.prod(w_shape[:-2] + [in_features])
-            w_init = initializers.truncated_normal(stddev=1.0 / np.sqrt(fan_in))
+            w_init = jax.nn.initializers.normal(stddev=1.0 / np.sqrt(fan_in))
         if b_init is None:
-            b_init = initializers.zeros
+            b_init = jax.nn.initializers.zeros
 
-        self.register_parameter("weight", w_init(w_shape, jnp.float32, w_rng_key))
+        self.weight = w_init(w_rng_key, w_shape)
         b_shape = [out_features]
-        self.register_parameter("bias", b_init(b_shape, jnp.float32, b_rng_key))
+        self.bias = b_init(b_rng_key, b_shape)
 
     def __call__(self, x: jnp.ndarray) -> jnp.ndarray:
         assert len(x.shape) == len(self.kernel_format)
@@ -400,7 +397,7 @@ class ConvTranspose(Module):
             "stride": self.stride,
             "with_bias": self.with_bias,
         }
-        return super()._repr(info)
+        return self._repr(info)
 
 
 class Conv1DTranspose(ConvTranspose):
@@ -414,8 +411,8 @@ class Conv1DTranspose(ConvTranspose):
         stride: Union[int, Sequence[int]] = 1,
         padding: Union[str, Sequence[Tuple[int, int]]] = "SAME",
         with_bias: bool = True,
-        w_init: Optional[initializers.Initializer] = None,
-        b_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
+        b_init: Optional[Callable] = None,
         data_format: str = "NWC",
         *,
         name: Optional[str] = None,
@@ -434,8 +431,7 @@ class Conv1DTranspose(ConvTranspose):
             stride: Optional stride for the kernel. Either an integer or a sequence of
                 length 1. Defaults to 1.
             padding: Optional padding algorithm. Either ``VALID`` or ``SAME``.
-                Defaults to ``SAME``. See:
-                https://www.tensorflow.org/xla/operation_semantics#conv_convolution.
+                Defaults to ``SAME``.
             with_bias: Whether to add a bias. By default, true.
             w_init: Optional weight initialization. By default, truncated normal.
             b_init: Optional bias initialization. By default, zeros.
@@ -476,8 +472,8 @@ class Conv2DTranspose(ConvTranspose):
         stride: Union[int, Sequence[int]] = 1,
         padding: Union[str, Sequence[Tuple[int, int]]] = "SAME",
         with_bias: bool = True,
-        w_init: Optional[initializers.Initializer] = None,
-        b_init: Optional[initializers.Initializer] = None,
+        w_init: Optional[Callable] = None,
+        b_init: Optional[Callable] = None,
         data_format: str = "NHWC",
         *,
         name: Optional[str] = None,
@@ -496,8 +492,7 @@ class Conv2DTranspose(ConvTranspose):
             stride: Optional stride for the kernel. Either an integer or a sequence of
                 length 1. Defaults to 1.
             padding: Optional padding algorithm. Either ``VALID`` or ``SAME``.
-                Defaults to ``SAME``. See:
-                https://www.tensorflow.org/xla/operation_semantics#conv_convolution.
+                Defaults to ``SAME``.
             with_bias: Whether to add a bias. By default, true.
             w_init: Optional weight initialization. By default, truncated normal.
             b_init: Optional bias initialization. By default, zeros.
